==> hibernate-core-6.1.5.Final-sources.jar: hbm/org/hibernate/boot/jaxb/hbm/spi/JaxbHbmOneToManyCollectionElementType.java <==

package org.hibernate.boot.jaxb.hbm.spi;

import java.io.Serializable;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for OneToManyCollectionElementType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OneToManyCollectionElementType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="class" type="{http://www.hibernate.org/xsd/orm/hbm}ClassNameType" /&gt;
 *       &lt;attribute name="embed-xml" type="{http://www.w3.org/2001/XMLSchema}boolean" /&gt;
 *       &lt;attribute name="entity-name" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="node" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="not-found" type="{http://www.hibernate.org/xsd/orm/hbm}NotFoundEnum" default="exception" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OneToManyCollectionElementType", namespace = "http://www.hibernate.org/xsd/orm/hbm")
public class JaxbHbmOneToManyCollectionElementType
    implements Serializable
{

    @XmlAttribute(name = "class")
    protected String clazz;
    @XmlAttribute(name = "embed-xml")
    protected Boolean embedXml;
    @XmlAttribute(name = "entity-name")
    protected String entityName;
    @XmlAttribute(name = "node")
    protected String node;
    @XmlAttribute(name = "not-found")
    protected JaxbHbmNotFoundEnum notFound;

    /**
     * Gets the value of the clazz property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getClazz() {
        return clazz;
    }

    /**
     * Sets the value of the clazz property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setClazz(String value) {
        this.clazz = value;
    }

    /**
     * Gets the value of the embedXml property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isEmbedXml() {
        return embedXml;
    }

    /**
     * Sets the value of the embedXml property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setEmbedXml(Boolean value) {
        this.embedXml = value;
    }

    /**
     * Gets the value of the entityName property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEntityName() {
        return entityName;
    }

    /**
     * Sets the value of the entityName property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEntityName(String value) {
        this.entityName = value;
    }

    /**
     * Gets the value of the node property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNode() {
        return node;
    }

    /**
     * Sets the value of the node property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNode(String value) {
        this.node = value;
    }

    /**
     * Gets the value of the notFound property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbHbmNotFoundEnum }
     *     
     */
    public JaxbHbmNotFoundEnum getNotFound() {
        if (notFound == null) {
            return JaxbHbmNotFoundEnum.EXCEPTION;
        } else {
            return notFound;
        }
    }

    /**
     * Sets the value of the notFound property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbHbmNotFoundEnum }
     *     
     */
    public void setNotFound(JaxbHbmNotFoundEnum value) {
        this.notFound = value;
    }

}

==> hibernate-core-6.4.8.Final-sources.jar: hbm/org/hibernate/boot/jaxb/hbm/spi/JaxbHbmOneToManyCollectionElementType.java <==

package org.hibernate.boot.jaxb.hbm.spi;

import java.io.Serializable;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for OneToManyCollectionElementType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="OneToManyCollectionElementType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="class" type="{http://www.hibernate.org/xsd/orm/hbm}ClassNameType" />
 *       <attribute name="embed-xml" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="entity-name" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="node" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="not-found" type="{http://www.hibernate.org/xsd/orm/hbm}NotFoundEnum" default="exception" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OneToManyCollectionElementType", namespace = "http://www.hibernate.org/xsd/orm/hbm")
public class JaxbHbmOneToManyCollectionElementType
    implements Serializable
{

    @XmlAttribute(name = "class")
    protected String clazz;
    @XmlAttribute(name = "embed-xml")
    protected Boolean embedXml;
    @XmlAttribute(name = "entity-name")
    protected String entityName;
    @XmlAttribute(name = "node")
    protected String node;
    @XmlAttribute(name = "not-found")
    protected JaxbHbmNotFoundEnum notFound;

    /**
     * Gets the value of the clazz property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getClazz() {
        return clazz;
    }

    /**
     * Sets the value of the clazz property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setClazz(String value) {
        this.clazz = value;
    }

    /**
     * Gets the value of the embedXml property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isEmbedXml() {
        return embedXml;
    }

    /**
     * Sets the value of the embedXml property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setEmbedXml(Boolean value) {
        this.embedXml = value;
    }

    /**
     * Gets the value of the entityName property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEntityName() {
        return entityName;
    }

    /**
     * Sets the value of the entityName property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEntityName(String value) {
        this.entityName = value;
    }

    /**
     * Gets the value of the node property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNode() {
        return node;
    }

    /**
     * Sets the value of the node property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNode(String value) {
        this.node = value;
    }

    /**
     * Gets the value of the notFound property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbHbmNotFoundEnum }
     *     
     */
    public JaxbHbmNotFoundEnum getNotFound() {
        if (notFound == null) {
            return JaxbHbmNotFoundEnum.EXCEPTION;
        } else {
            return notFound;
        }
    }

    /**
     * Sets the value of the notFound property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbHbmNotFoundEnum }
     *     
     */
    public void setNotFound(JaxbHbmNotFoundEnum value) {
        this.notFound = value;
    }

}
